## Features

* Flexible and automated oversight of heterogeneous hardware.
* The most mature and widely used open-source control system in quantum science.
* Multiple analysis-based feedback modes.
* Extensible plugin architecture (e.g. machine learning online optimisation).
* Readily integrates with other software, including image acquisition, analysis, and even other control systems.
* Compose experiments as human-readable Python code, leveraging modularity, revision control and re-use.
* Dynamic visualisation of experiment composition and results.
* Remote operation: different modules can run on physically separate hosts / single modules can be run on multiple hosts (including hardware supervisor, [blacs](https://github.com/labscript-suite/blacs)).
* Auto-generating user-interfaces.
* High-level scripting: all user-interface interaction can be programatically synthesised.